@@ -398,7 +398,8 @@ ebbm_connect_user (EBookBackendMAPI *ebma,
 			g_object_unref (old_conn);
 
 		if (!priv->conn || mapi_error) {
-			gboolean is_network_error = mapi_error && mapi_error->domain != E_MAPI_ERROR;
+			gboolean is_network_error = g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_NETWORK_ERROR) ||
+				(mapi_error && mapi_error->domain != E_MAPI_ERROR);
 
 			if (priv->conn) {
 				g_object_unref (priv->conn);
@@ -761,10 +762,14 @@ ebbm_book_view_thread (gpointer data)
 
 			e_book_backend_mapi_update_view_by_cache (bvtd->ebma, bvtd->book_view, &error);
 		} else if (ebmac->op_list_known_uids && ebmac->op_transfer_contacts) {
-			const gchar *sexp = e_data_book_view_get_card_query (bvtd->book_view);
+			EBookBackendSExp *sexp;
+			const gchar *query;
+
+			sexp = e_data_book_view_get_sexp (bvtd->book_view);
+			query = e_book_backend_sexp_text (sexp);
 
 			/* search only if not searching for everything */
-			if (sexp && *sexp && g_ascii_strcasecmp (sexp, "(contains \"x-evolution-any-field\" \"\")") != 0) {
+			if (query && *query && g_ascii_strcasecmp (query, "(contains \"x-evolution-any-field\" \"\")") != 0) {
 				struct ListKnownUidsData lku = { 0 };
 				GHashTable *local_known_uids, *server_known_uids;
 
@@ -776,7 +781,7 @@ ebbm_book_view_thread (gpointer data)
 				lku.uid_to_rev = server_known_uids;
 				lku.latest_last_modify = 0;
 
-				ebmac->op_list_known_uids (bvtd->ebma, e_mapi_book_utils_build_sexp_restriction, (gpointer) sexp, &lku, bvtd->cancellable, &error);
+				ebmac->op_list_known_uids (bvtd->ebma, e_mapi_book_utils_build_sexp_restriction, (gpointer) query, &lku, bvtd->cancellable, &error);
 
 				if (!g_cancellable_is_cancelled (bvtd->cancellable)) {
 					GSList *uids = NULL;
@@ -836,7 +841,6 @@ ebbm_book_view_thread (gpointer data)
 
 typedef enum {
 	OP_OPEN,
-	OP_REMOVE,
 
 	OP_CREATE_CONTACTS,
 	OP_REMOVE_CONTACTS,
@@ -912,16 +916,6 @@ ebbm_operation_cb (OperationBase *op, gboolean cancelled, EBookBackend *backend)
 			e_data_book_respond_open (op->book, op->opid, error);
 		}
 	} break;
-	case OP_REMOVE: {
-		if (!cancelled) {
-			if (ebmac->op_remove)
-				ebmac->op_remove (ebma, op->cancellable, &error);
-			else
-				error = EDB_ERROR (NOT_SUPPORTED);
-
-			e_data_book_respond_remove (op->book, op->opid, error);
-		}
-	} break;
 	case OP_CREATE_CONTACTS: {
 		OperationStrSlist *ops = (OperationStrSlist *) op;
 
@@ -1121,35 +1115,6 @@ ebbm_operation_cb (OperationBase *op, gboolean cancelled, EBookBackend *backend)
 	e_mapi_utils_unref_in_thread (G_OBJECT (backend));
 }
 
-static void
-base_op_abstract (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, OperationType ot)
-{
-	OperationBase *op;
-	EBookBackendMAPI *ebbm;
-	EBookBackendMAPIPrivate *priv;
-
-	g_return_if_fail (backend != NULL);
-	g_return_if_fail (E_IS_BOOK_BACKEND_MAPI (backend));
-
-	ebbm = E_BOOK_BACKEND_MAPI (backend);
-	priv = ebbm->priv;
-	g_return_if_fail (priv != NULL);
-
-	g_object_ref (ebbm);
-	if (book)
-		g_object_ref (book);
-	if (cancellable)
-		g_object_ref (cancellable);
-
-	op = g_new0 (OperationBase, 1);
-	op->ot = ot;
-	op->book = book;
-	op->opid = opid;
-	op->cancellable = cancellable;
-
-	e_mapi_operation_queue_push (priv->op_queue, op);
-}
-
 static void
 str_op_abstract (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *str, OperationType ot)
 {
@@ -1216,13 +1181,6 @@ str_slist_op_abstract (EBookBackend *backend, EDataBook *book, guint32 opid, GCa
 	e_mapi_operation_queue_push (priv->op_queue, op);
 }
 
-#define BASE_OP_DEF(_func, _ot)								\
-static void										\
-_func (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable)	\
-{											\
-	base_op_abstract (backend, book, opid, cancellable, _ot);			\
-}
-
 #define STR_OP_DEF(_func, _ot)							\
 static void									\
 _func (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cancellable, const gchar *str)	\
@@ -1237,7 +1195,6 @@ _func (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable *cance
 	str_slist_op_abstract (backend, book, opid, cancellable, str_slist, _ot);	\
 }
 
-BASE_OP_DEF (ebbm_op_remove, OP_REMOVE)
 STR_SLIST_OP_DEF (ebbm_op_create_contacts, OP_CREATE_CONTACTS)
 STR_SLIST_OP_DEF (ebbm_op_modify_contacts, OP_MODIFY_CONTACTS)
 STR_SLIST_OP_DEF (ebbm_op_remove_contacts, OP_REMOVE_CONTACTS)
@@ -1276,7 +1233,7 @@ ebbm_op_open (EBookBackend *backend, EDataBook *book, guint32 opid, GCancellable
 }
 
 static void
-ebbm_op_start_book_view (EBookBackend *backend, EDataBookView *book_view)
+ebbm_op_start_view (EBookBackend *backend, EDataBookView *book_view)
 {
 	OperationBookView *op;
 	EBookBackendMAPI *ebbm;
@@ -1306,7 +1263,7 @@ ebbm_op_start_book_view (EBookBackend *backend, EDataBookView *book_view)
 }
 
 static void
-ebbm_op_stop_book_view (EBookBackend *backend, EDataBookView *book_view)
+ebbm_op_stop_view (EBookBackend *backend, EDataBookView *book_view)
 {
 	OperationBookView *op;
 	EBookBackendMAPI *ebbm;
@@ -1413,14 +1370,13 @@ e_book_backend_mapi_class_init (EBookBackendMAPIClass *klass)
 	object_class->dispose			= ebbm_dispose;
 
 	backend_class->open			= ebbm_op_open;
-	backend_class->remove			= ebbm_op_remove;
 	backend_class->create_contacts		= ebbm_op_create_contacts;
 	backend_class->remove_contacts		= ebbm_op_remove_contacts;
 	backend_class->modify_contacts		= ebbm_op_modify_contacts;
 	backend_class->get_contact		= ebbm_op_get_contact;
 	backend_class->get_contact_list		= ebbm_op_get_contact_list;
-	backend_class->start_book_view		= ebbm_op_start_book_view;
-	backend_class->stop_book_view		= ebbm_op_stop_book_view;
+	backend_class->start_view		= ebbm_op_start_view;
+	backend_class->stop_view		= ebbm_op_stop_view;
 	backend_class->get_backend_property	= ebbm_op_get_backend_property;
 	klass->op_open				= ebbm_open;
 	klass->op_remove			= ebbm_remove;
@@ -1527,6 +1483,7 @@ e_book_backend_mapi_update_view_by_cache (EBookBackendMAPI *ebma, EDataBookView
 {
 	gint i = 0;
 	const gchar *query = NULL;
+	EBookBackendSExp *sexp;
 	EBookBackendSqliteDB *db = NULL;
 	GSList *hits, *l;
 
@@ -1535,7 +1492,9 @@ e_book_backend_mapi_update_view_by_cache (EBookBackendMAPI *ebma, EDataBookView
 	g_return_if_fail (book_view != NULL);
 	g_return_if_fail (E_IS_DATA_BOOK_VIEW (book_view));
 
-	query = e_data_book_view_get_card_query (book_view);
+	sexp = e_data_book_view_get_sexp (book_view);
+	query = e_book_backend_sexp_text (sexp);
+
 	e_book_backend_mapi_get_db (ebma, &db);
 
 	g_return_if_fail (db != NULL);
@@ -1594,8 +1553,6 @@ e_book_backend_mapi_notify_contact_update (EBookBackendMAPI *ebma,
 	   it can happen when cache is filling and the book view started later */
 	if (!book_view)
 		book_view = ebbm_pick_book_view (ebma);
-	else
-		g_object_ref (book_view);
 
 	if (book_view) {
 		if (!e_book_backend_mapi_book_view_is_running (ebma, book_view))
